@@ -331,7 +331,20 @@ class AuthenticateCognitoActionProps:
             app.synth()
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AuthenticateCognitoActionProps.__init__)
+            def stub(
+                *,
+                next: aws_cdk.aws_elasticloadbalancingv2.ListenerAction,
+                user_pool: aws_cdk.aws_cognito.IUserPool,
+                user_pool_client: aws_cdk.aws_cognito.IUserPoolClient,
+                user_pool_domain: aws_cdk.aws_cognito.IUserPoolDomain,
+                authentication_request_extra_params: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                on_unauthenticated_request: typing.Optional[aws_cdk.aws_elasticloadbalancingv2.UnauthenticatedAction] = None,
+                scope: typing.Optional[builtins.str] = None,
+                session_cookie_name: typing.Optional[builtins.str] = None,
+                session_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument next", value=next, expected_type=type_hints["next"])
             check_type(argname="argument user_pool", value=user_pool, expected_type=type_hints["user_pool"])
             check_type(argname="argument user_pool_client", value=user_pool_client, expected_type=type_hints["user_pool_client"])
